==> nextcloud-19.0.8.tgz: nextcloud/apps/theming/l10n/af.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laai voorskou…",
    "Saved" : "Bewaar",
    "Admin" : "Admin",
    "a safe home for all your data" : "’n veilige tuiste vir al u data",
    "Name cannot be empty" : "Naam kan nie leeg wees nie",
    "The given name is too long" : "Die gegewe naam is te lank",
    "The given web address is too long" : "Die gegewe webadres is te lank",
    "The given legal notice address is too long" : "Die gegewe regskennisgewingsadres is te lank",
    "The given privacy policy address is too long" : "Die gegewe privaatheidsbeleidadres is te lank",
    "The given slogan is too long" : "Gegewe slagspreuk is te lank",
    "The given color is invalid" : "Die gegewe kleur is ongeldig",
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "No file uploaded" : "Geen lêer opgelaai",
    "Legal notice" : "Regskennisgewing",
    "Privacy policy" : "Privaatheidsbeleid",
    "Adjust the Nextcloud theme" : "Pas die Nextcloud-tema aan",
    "Open documentation" : "Open dokumentasie",
    "Name" : "Naam",
    "Reset to default" : "Herstel na verstek",
    "Web link" : "Webskakel",
    "Slogan" : "Slagspreuk",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Laai nuwe logo op",
    "Login image" : "Aantekenbeeld",
    "Upload new login background" : "Laai nuwe aantekenagtergrond op",
    "Remove background image" : "Verwyder agtergrondbeeld",
    "Advanced options" : "Gevorderde opsies",
    "Legal notice link" : "Regskennisgewingskakel",
    "Privacy policy link" : "Privaatheidsbeleidskakel",
    "Unsupported image type" : "Onondersteunde beeldtipe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/theming/l10n/af.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laai voorskou…",
    "Admin" : "Admin",
    "Saved" : "Bewaar",
    "a safe home for all your data" : "’n veilige tuiste vir al u data",
    "Name cannot be empty" : "Naam kan nie leeg wees nie",
    "The given name is too long" : "Die gegewe naam is te lank",
    "The given web address is too long" : "Die gegewe webadres is te lank",
    "The given legal notice address is too long" : "Die gegewe regskennisgewingsadres is te lank",
    "The given privacy policy address is too long" : "Die gegewe privaatheidsbeleidadres is te lank",
    "The given slogan is too long" : "Gegewe slagspreuk is te lank",
    "The given color is invalid" : "Die gegewe kleur is ongeldig",
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "No file uploaded" : "Geen lêer opgelaai",
    "Dark theme" : "Donker Tema",
    "Dyslexia font" : "Disleksie-font",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is ’n gratis lettertipe/font wat ontwerp is om sommige van die algemene leesfoute wat deur disleksie veroorsaak word, te versag.",
    "High contrast mode" : "Hoëkontrasmodus",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "’n Hoëkontrasmodus om u navigasie te vergemaklik. Visuele kwaliteit sal verminder word, maar die duidelikheid sal verbeter.",
    "Legal notice" : "Regskennisgewing",
    "Privacy policy" : "Privaatheidsbeleid",
    "Adjust the Nextcloud theme" : "Pas die Nextcloud-tema aan",
    "Open documentation" : "Open dokumentasie",
    "Name" : "Naam",
    "Reset to default" : "Herstel na verstek",
    "Web link" : "Webskakel",
    "Slogan" : "Slagspreuk",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Laai nuwe logo op",
    "Login image" : "Aantekenbeeld",
    "Upload new login background" : "Laai nuwe aantekenagtergrond op",
    "Remove background image" : "Verwyder agtergrondbeeld",
    "Advanced options" : "Gevorderde opsies",
    "Legal notice link" : "Regskennisgewingskakel",
    "Privacy policy link" : "Privaatheidsbeleidskakel"
},
"nplurals=2; plural=(n != 1);");
